<p align="center">
  <br>
  <a href="#">
    <img src="logo.svg" height="100" width="100" alt="Mersad Cryptography Library"/>
  </a>
</p>

<h1 align="center">Mersad Cryptography Library</h1>
<h3 align="center">A side project of a Telecommunication student who loves ciphers.</h3>
<p align="center">

<p align="center">
  <a title="Open Source" href="https://opensource.com/resources/what-open-source" target="_blank">
    <img src="https://img.shields.io/badge/Open%20Source-Forever-brightgreen?logo=open-source-initiative&style=flat-square" alt="Open Source">
  </a>
  <a title="License: AGPLv3" href="https://www.opensource.org/licenses/AGPL-3.0" target="_blank">
    <img src="https://img.shields.io/github/license/azadeh-afzar/Mersad-Cryptography-Library?logo=gnu&style=flat-square" alt="License: AGPL v3">
  </a>
  <a title="Language counter" href="#" target="_blank">
    <img src="https://img.shields.io/github/languages/count/azadeh-afzar/Mersad-Cryptography-Library?logo=gitlab&style=flat-square" alt="Language counter">
  </a>
  <a title="Top language" href="#" target="_blank">
    <img src="https://img.shields.io/github/languages/top/azadeh-afzar/Mersad-Cryptography-Library?logo=gitlab&style=flat-square" alt="Top language">
  </a>
  <a title="GitLab: pipeline status" href="https://gitlab.com/Azadeh-Afzar/Cryptography/Mersad-Cryptography-Library/commits/master" target="_blank">
    <img src="https://img.shields.io/gitlab/pipeline/Cryptography/Mersad-Cryptography-Library?gitlab_url=https%3A%2F%2Fgitlab.com%2FAzadeh-Afzar&logo=gitlab&style=flat-square"  alt="pipeline status" />
  </a>
  <a title="Travis CI: build status" href="https://travis-ci.org/azadeh-afzar/Mersad-Cryptography-Library" target="_blank">
    <img src="https://img.shields.io/travis/azadeh-afzar/Mersad-Cryptography-Library/master?logo=travis&style=flat-square"  alt="travis build status" />
  </a>
  <a title="Test Coverage: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library" target="_blank">
    <img src="https://img.shields.io/codeclimate/coverage/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate"/>
  </a>
  
  <br>
  
  <a title="Code Quality: Codefactor.io" href="https://www.codefactor.io/repository/github/azadeh-afzar/mersad-cryptography-library" target="_blank">
    <img src="https://www.codefactor.io/repository/github/azadeh-afzar/mersad-cryptography-library/badge?style=flat-square" alt="CodeFactor"/>
  </a>
  <a title="Code Quality: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/maintainability/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate rating"/>
  </a>
  <a title="Code Quality: Scrutinizer-ci.com" href="https://scrutinizer-ci.com/g/azadeh-afzar/Mersad-Cryptography-Library/?branch=master" target="_blank">
    <img src="https://img.shields.io/scrutinizer/quality/g/azadeh-afzar/Mersad-Cryptography-Library/master?logo=scrutinizer&style=flat-square" alt="Scrutinizer-ci rating"/>
  </a>
  <a title="Code Technical Debt: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/tech-debt/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate technical debt"/>
  </a>
  <a title="Code Issues: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/issues/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate issues"/>
  </a>
  
  <br>
  
  <a title="PyPi: Mersad version" href="https://pypi.org/project/mersad" target="_blank">
    <img src="https://img.shields.io/pypi/v/mersad?logo=pypi&style=flat-square" alt="PyPI version">
  </a>
  <a title="PyPi: Mersad downloads" href="https://pypi.org/project/mersad" target="_blank">
    <img src="https://img.shields.io/pypi/dm/mersad?logo=pypi&style=flat-square" alt="PyPI downloads">
  </a>
  <a title="PyPi: version support" href="https://pypi.org/project/mersad" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/mersad?logo=pypi&style=flat-square" alt="Supported Python versions">
  </a>
</p>

> If you want to do serious jobs with this tool, prepare to be fired :fire:! 

## Why is Gamora?
I just wanted to practice some simple Python Project with a little continues integration
training and automated releasing to packaging sources like pypi and I loved ciphers,
I don't know why did I end up here writing this for you! (even like if there is any 
"you" out there looking on this little side project of mine.)

So if you want to send unbreakable messages to your friends with ancient algorithms
without using pen and paper, Mersad can help you. (but seriously, unbreakable? c'mon!)


## Quick start
I'm sure you have worked with Python before and you are familiar with how to download
a package via pip, so here is how to install this totally (not at all) secure package:

```bash
# 1. if are an uncivilised savage living in a hell of dependency conflicts who doesn't 
# even heard of virtual environments and always install packages in sudo mode, here you go:
sudo -H pip3 install mersad
# or just use a little bit better non-sudo thing
pip3 install --user mersad

# 2. if you are a man of culture, activate your virtual environment and do this:
pip3 install mersad
# pipenv is also a good thing to use
pipenv install mersad
```

## How it works


### Notes


## Contribution

If you want to contribute to this project, please read [CONTRIBUTING](CONTRIBUTING.md).

## Code of Conduct

Visit the [Code of Conduct](CODE_OF_CONDUCT.md).

## Roadmap

Visit the [Roadmap](ROADMAP.md) to keep track of which features we are currently working on.

## License

Licensed under the [AGPLv3](LICENSE).

## Attribution

